Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(811)

Unified Diff: net/url_request/url_request_error_job.h

Issue 5607004: net: Remove typedef net::URLRequestJob URLRequestJob; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebased 2 Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_request_data_job.cc ('k') | net/url_request/url_request_error_job.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request_error_job.h
diff --git a/net/url_request/url_request_error_job.h b/net/url_request/url_request_error_job.h
index 6e7c8793c7c0934a351cc20fab3987be0e483faf..58729c8c6e9733d37388ba3f13cd44d55222541d 100644
--- a/net/url_request/url_request_error_job.h
+++ b/net/url_request/url_request_error_job.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Invalid URLs go through this URLRequestJob class rather than being passed
// to the default job handler.
#ifndef NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_
#define NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_
@@ -11,7 +11,7 @@
#include "net/url_request/url_request_job.h"
-class URLRequestErrorJob : public URLRequestJob {
+class URLRequestErrorJob : public net::URLRequestJob {
public:
URLRequestErrorJob(net::URLRequest* request, int error);
« no previous file with comments | « net/url_request/url_request_data_job.cc ('k') | net/url_request/url_request_error_job.cc » ('j') | no next file with comments »
@@ -2,8 +2,8 @@
// found in the LICENSE file.
//
-// Invalid URLs go through this URLRequestJob class rather than being passed
-// to the default job handler.
+// Invalid URLs go through this net::URLRequestJob class rather than being
+// passed to the default job handler.
#ifndef NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_
#define NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_

Powered by Google App Engine
This is Rietveld 408576698